Documentation
¶
Overview ¶
Package metrics provides Prometheus metrics for Contour.
Index ¶
Constants ¶
const ( IngressRouteTotalGauge = "contour_ingressroute_total" IngressRouteRootTotalGauge = "contour_ingressroute_root_total" IngressRouteInvalidGauge = "contour_ingressroute_invalid_total" IngressRouteValidGauge = "contour_ingressroute_valid_total" IngressRouteOrphanedGauge = "contour_ingressroute_orphaned_total" IngressRouteDAGRebuildGauge = "contour_ingressroute_dagrebuild_timestamp" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type IngressRouteMetric ¶
type IngressRouteMetric struct {
Total map[Meta]int
Valid map[Meta]int
Invalid map[Meta]int
Orphaned map[Meta]int
Root map[Meta]int
}
IngressRouteMetric stores various metrics for IngressRoute objects
type Meta ¶
type Meta struct {
VHost, Namespace string
}
Meta holds the vhost and namespace of a metric object
type Metrics ¶
type Metrics struct {
CacheHandlerOnUpdateSummary prometheus.Summary
ResourceEventHandlerSummary *prometheus.SummaryVec
// contains filtered or unexported fields
}
Metrics provide Prometheus metrics for the app
func NewMetrics ¶
func NewMetrics(registry *prometheus.Registry) *Metrics
NewMetrics creates a new set of metrics and registers them with the supplied registry.
func (*Metrics) SetDAGRebuiltMetric ¶
SetDAGRebuiltMetric records the last time the DAG was rebuilt
func (*Metrics) SetIngressRouteMetric ¶
func (m *Metrics) SetIngressRouteMetric(metrics IngressRouteMetric)
SetIngressRouteMetric sets metric values for a set of IngressRoutes
Click to show internal directories.
Click to hide internal directories.